mix commit (conventional_commits v0.2.1)

This will create a REPL that allows the user to create a commit message following specifications defined by Conventional Commits when the user requests mix commit.